@@ -20,14 +20,15 @@
  * which can be found at <https://www.eyrie.org/~eagle/software/rra-c-util/>.
  *
  * Written by Russ Allbery <eagle@eyrie.org>
+ * Copyright 2010-2011, 2014
+ *     The Board of Trustees of the Leland Stanford Junior University
  *
- * The authors hereby relinquish any claim to any copyright that they may have
- * in this work, whether granted under contract or by operation of law or
- * international treaty, and hereby commit to the public, at large, that they
- * shall not, at any time in the future, seek to enforce any copyright in this
- * work against any person or entity, or prevent any person or entity from
- * copying, publishing, distributing or creating derivative works of this
- * work.
+ * Copying and distribution of this file, with or without modification, are
+ * permitted in any medium without royalty provided the copyright notice and
+ * this notice are preserved.  This file is offered as-is, without any
+ * warranty.
+ *
+ * SPDX-License-Identifier: FSFAP
  */
 
 #ifndef PAM_UTIL_VECTOR_H
@@ -51,8 +52,7 @@ BEGIN_DECLS
 #pragma GCC visibility push(hidden)
 
 /* Create a new, empty vector.  Returns NULL on memory allocation failure. */
-struct vector *vector_new(void)
-    __attribute__((__malloc__));
+struct vector *vector_new(void) __attribute__((__malloc__));
 
 /*
  * Create a new vector that's a copy of an existing vector.  Returns NULL on
@@ -73,16 +73,14 @@ bool vector_add(struct vector *, const char *string)
  * in vector_add if it's known in advance how many entries there will be.
  * Returns false on failure to allocate memory.
  */
-bool vector_resize(struct vector *, size_t size)
-    __attribute__((__nonnull__));
+bool vector_resize(struct vector *, size_t size) __attribute__((__nonnull__));
 
 /*
  * Reset the number of elements to zero, freeing all of the strings for a
  * regular vector, but not freeing the strings array (to cut down on memory
  * allocations if the vector will be reused).
  */
-void vector_clear(struct vector *)
-    __attribute__((__nonnull__));
+void vector_clear(struct vector *) __attribute__((__nonnull__));
 
 /* Free the vector and all resources allocated for it. */
 void vector_free(struct vector *);
