@@ -10,7 +10,7 @@
  * which can be found at <https://www.eyrie.org/~eagle/software/rra-c-util/>.
  *
  * Written by Russ Allbery <eagle@eyrie.org>
- * Copyright 2016, 2018, 2020 Russ Allbery <eagle@eyrie.org>
+ * Copyright 2016, 2018, 2020-2021 Russ Allbery <eagle@eyrie.org>
  * Copyright 2011-2012, 2014
  *     The Board of Trustees of the Leland Stanford Junior University
  *
@@ -322,7 +322,7 @@ run_script(const char *file, const struct script_config *config)
         config->callback(pamh, config, config->data);
 
     /* Free memory and return. */
-    pam_end(pamh, PAM_SUCCESS);
+    pam_end(pamh, work->end_flags);
     action = work->actions;
     while (action != NULL) {
         free(action->name);
