@@ -5,7 +5,8 @@
  * which can be found at <https://www.eyrie.org/~eagle/software/rra-c-util/>.
  *
  * Written by Russ Allbery <eagle@eyrie.org>
- * Copyright 2010, 2011, 2012, 2013
+ * Copyright 2020 Russ Allbery <eagle@eyrie.org>
+ * Copyright 2010-2013
  *     The Board of Trustees of the Leland Stanford Junior University
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -25,6 +26,8 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
+ *
+ * SPDX-License-Identifier: MIT
  */
 
 #include <config.h>
@@ -40,30 +43,30 @@
 #include <tests/tap/string.h>
 
 /* Test a normal PAM logging function. */
-#define TEST(func, p, n)                                                \
-    do {                                                                \
-        (func)(args, "%s", "foo");                                      \
-        seen = pam_output();                                            \
-        is_int((p), seen->lines[0].priority, "priority %d", (p));       \
-        is_string("foo", seen->lines[0].line, "line %s", (n));          \
-        pam_output_free(seen);                                          \
-    } while (0);
+#define TEST(func, p, n)                                          \
+    do {                                                          \
+        (func)(args, "%s", "foo");                                \
+        seen = pam_output();                                      \
+        is_int((p), seen->lines[0].priority, "priority %d", (p)); \
+        is_string("foo", seen->lines[0].line, "line %s", (n));    \
+        pam_output_free(seen);                                    \
+    } while (0)
 
 /* Test a PAM error logging function. */
-#define TEST_PAM(func, c, p, n)                                         \
-    do {                                                                \
-        (func)(args, (c), "%s", "bar");                                 \
-        if ((c) == PAM_SUCCESS)                                         \
-            expected = strdup("bar");                                   \
-        else                                                            \
-            basprintf(&expected, "%s: %s", "bar",                       \
-                      pam_strerror(args->pamh, c));                     \
-        seen = pam_output();                                            \
-        is_int((p), seen->lines[0].priority, "priority %s", (n));       \
-        is_string(expected, seen->lines[0].line, "line %s", (n));       \
-        pam_output_free(seen);                                          \
-        free(expected);                                                 \
-    } while (0);
+#define TEST_PAM(func, c, p, n)                                   \
+    do {                                                          \
+        (func)(args, (c), "%s", "bar");                           \
+        if ((c) == PAM_SUCCESS)                                   \
+            expected = strdup("bar");                             \
+        else                                                      \
+            basprintf(&expected, "%s: %s", "bar",                 \
+                      pam_strerror(args->pamh, c));               \
+        seen = pam_output();                                      \
+        is_int((p), seen->lines[0].priority, "priority %s", (n)); \
+        is_string(expected, seen->lines[0].line, "line %s", (n)); \
+        pam_output_free(seen);                                    \
+        free(expected);                                           \
+    } while (0)
 
 /* Test a PAM Kerberos error logging function .*/
 #define TEST_KRB5(func, p, n)                                             \
@@ -81,7 +84,7 @@
         pam_output_free(seen);                                            \
         free(expected);                                                   \
         krb5_free_error_message(args->ctx, msg);                          \
-    } while (0);
+    } while (0)
 
 
 int
@@ -89,7 +92,7 @@ main(void)
 {
     pam_handle_t *pamh;
     struct pam_args *args;
-    struct pam_conv conv = { NULL, NULL };
+    struct pam_conv conv = {NULL, NULL};
     char *expected;
     struct output *seen;
 #ifdef HAVE_KRB5
@@ -104,28 +107,28 @@ main(void)
     args = putil_args_new(pamh, 0);
     if (args == NULL)
         bail("cannot create PAM argument struct");
-    TEST(putil_crit,  LOG_CRIT,  "putil_crit");
-    TEST(putil_err,   LOG_ERR,   "putil_err");
+    TEST(putil_crit, LOG_CRIT, "putil_crit");
+    TEST(putil_err, LOG_ERR, "putil_err");
     putil_debug(args, "%s", "foo");
     ok(pam_output() == NULL, "putil_debug without debug on");
     args->debug = true;
     TEST(putil_debug, LOG_DEBUG, "putil_debug");
     args->debug = false;
 
-    TEST_PAM(putil_crit_pam,  PAM_SYSTEM_ERR, LOG_CRIT,  "putil_crit_pam S");
-    TEST_PAM(putil_crit_pam,  PAM_BUF_ERR,    LOG_CRIT,  "putil_crit_pam B");
-    TEST_PAM(putil_crit_pam,  PAM_SUCCESS,    LOG_CRIT,  "putil_crit_pam ok");
-    TEST_PAM(putil_err_pam,   PAM_SYSTEM_ERR, LOG_ERR,   "putil_err_pam");
+    TEST_PAM(putil_crit_pam, PAM_SYSTEM_ERR, LOG_CRIT, "putil_crit_pam S");
+    TEST_PAM(putil_crit_pam, PAM_BUF_ERR, LOG_CRIT, "putil_crit_pam B");
+    TEST_PAM(putil_crit_pam, PAM_SUCCESS, LOG_CRIT, "putil_crit_pam ok");
+    TEST_PAM(putil_err_pam, PAM_SYSTEM_ERR, LOG_ERR, "putil_err_pam");
     putil_debug_pam(args, PAM_SYSTEM_ERR, "%s", "bar");
     ok(pam_output() == NULL, "putil_debug_pam without debug on");
     args->debug = true;
     TEST_PAM(putil_debug_pam, PAM_SYSTEM_ERR, LOG_DEBUG, "putil_debug_pam");
-    TEST_PAM(putil_debug_pam, PAM_SUCCESS,    LOG_DEBUG, "putil_debug_pam ok");
+    TEST_PAM(putil_debug_pam, PAM_SUCCESS, LOG_DEBUG, "putil_debug_pam ok");
     args->debug = false;
 
 #ifdef HAVE_KRB5
-    TEST_KRB5(putil_crit_krb5,  LOG_CRIT,  "putil_crit_krb5");
-    TEST_KRB5(putil_err_krb5,   LOG_ERR,   "putil_err_krb5");
+    TEST_KRB5(putil_crit_krb5, LOG_CRIT, "putil_crit_krb5");
+    TEST_KRB5(putil_err_krb5, LOG_ERR, "putil_err_krb5");
     code = krb5_parse_name(args->ctx, "foo@bar@EXAMPLE.COM", &princ);
     putil_debug_krb5(args, code, "%s", "krb");
     ok(pam_output() == NULL, "putil_debug_krb5 without debug on");
